==> glitter_proto-0.1.0.tar.gz: glitter_proto-0.1.0/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['glitter_proto',
 'glitter_proto.blockved',
 'glitter_proto.blockved.glitterchain',
 'glitter_proto.blockved.glitterchain.index',
 'glitter_proto.cosmos',
 'glitter_proto.cosmos.auth',
 'glitter_proto.cosmos.auth.v1beta1',
 'glitter_proto.cosmos.authz',
 'glitter_proto.cosmos.authz.v1beta1',
 'glitter_proto.cosmos.bank',
 'glitter_proto.cosmos.bank.v1beta1',
 'glitter_proto.cosmos.base',
 'glitter_proto.cosmos.base.abci',
 'glitter_proto.cosmos.base.abci.v1beta1',
 'glitter_proto.cosmos.base.kv',
 'glitter_proto.cosmos.base.kv.v1beta1',
 'glitter_proto.cosmos.base.query',
 'glitter_proto.cosmos.base.query.v1beta1',
 'glitter_proto.cosmos.base.reflection',
 'glitter_proto.cosmos.base.reflection.v1beta1',
 'glitter_proto.cosmos.base.reflection.v2alpha1',
 'glitter_proto.cosmos.base.snapshots',
 'glitter_proto.cosmos.base.snapshots.v1beta1',
 'glitter_proto.cosmos.base.store',
 'glitter_proto.cosmos.base.store.v1beta1',
 'glitter_proto.cosmos.base.tendermint',
 'glitter_proto.cosmos.base.tendermint.v1beta1',
 'glitter_proto.cosmos.base.v1beta1',
 'glitter_proto.cosmos.capability',
 'glitter_proto.cosmos.capability.v1beta1',
 'glitter_proto.cosmos.crisis',
 'glitter_proto.cosmos.crisis.v1beta1',
 'glitter_proto.cosmos.crypto',
 'glitter_proto.cosmos.crypto.ed25519',
 'glitter_proto.cosmos.crypto.multisig',
 'glitter_proto.cosmos.crypto.multisig.v1beta1',
 'glitter_proto.cosmos.crypto.secp256k1',
 'glitter_proto.cosmos.crypto.secp256r1',
 'glitter_proto.cosmos.distribution',
 'glitter_proto.cosmos.distribution.v1beta1',
 'glitter_proto.cosmos.evidence',
 'glitter_proto.cosmos.evidence.v1beta1',
 'glitter_proto.cosmos.feegrant',
 'glitter_proto.cosmos.feegrant.v1beta1',
 'glitter_proto.cosmos.genutil',
 'glitter_proto.cosmos.genutil.v1beta1',
 'glitter_proto.cosmos.gov',
 'glitter_proto.cosmos.gov.v1beta1',
 'glitter_proto.cosmos.mint',
 'glitter_proto.cosmos.mint.v1beta1',
 'glitter_proto.cosmos.params',
 'glitter_proto.cosmos.params.v1beta1',
 'glitter_proto.cosmos.slashing',
 'glitter_proto.cosmos.slashing.v1beta1',
 'glitter_proto.cosmos.staking',
 'glitter_proto.cosmos.staking.v1beta1',
 'glitter_proto.cosmos.tx',
 'glitter_proto.cosmos.tx.signing',
 'glitter_proto.cosmos.tx.signing.v1beta1',
 'glitter_proto.cosmos.tx.v1beta1',
 'glitter_proto.cosmos.upgrade',
 'glitter_proto.cosmos.upgrade.v1beta1',
 'glitter_proto.cosmos.vesting',
 'glitter_proto.cosmos.vesting.v1beta1',
 'glitter_proto.cosmos_proto',
 'glitter_proto.cosmwasm',
 'glitter_proto.cosmwasm.wasm',
 'glitter_proto.cosmwasm.wasm.v1',
 'glitter_proto.ethermint',
 'glitter_proto.ethermint.crypto',
 'glitter_proto.ethermint.crypto.v1',
 'glitter_proto.ethermint.crypto.v1.ethsecp256k1',
 'glitter_proto.ethermint.evm',
 'glitter_proto.ethermint.evm.v1',
 'glitter_proto.ethermint.feemarket',
 'glitter_proto.ethermint.feemarket.v1',
 'glitter_proto.ethermint.types',
 'glitter_proto.ethermint.types.v1',
 'glitter_proto.gogoproto',
 'glitter_proto.google',
 'glitter_proto.google.api',
 'glitter_proto.google.protobuf',
 'glitter_proto.google.protobuf.compiler',
 'glitter_proto.ibc',
 'glitter_proto.ibc.applications',
 'glitter_proto.ibc.applications.fee',
 'glitter_proto.ibc.applications.fee.v1',
 'glitter_proto.ibc.applications.interchain_accounts',
 'glitter_proto.ibc.applications.interchain_accounts.controller',
 'glitter_proto.ibc.applications.interchain_accounts.controller.v1',
 'glitter_proto.ibc.applications.interchain_accounts.host',
 'glitter_proto.ibc.applications.interchain_accounts.host.v1',
 'glitter_proto.ibc.applications.interchain_accounts.v1',
 'glitter_proto.ibc.applications.transfer',
 'glitter_proto.ibc.applications.transfer.v1',
 'glitter_proto.ibc.applications.transfer.v2',
 'glitter_proto.ibc.core',
 'glitter_proto.ibc.core.channel',
 'glitter_proto.ibc.core.channel.v1',
 'glitter_proto.ibc.core.client',
 'glitter_proto.ibc.core.client.v1',
 'glitter_proto.ibc.core.commitment',
 'glitter_proto.ibc.core.commitment.v1',
 'glitter_proto.ibc.core.connection',
 'glitter_proto.ibc.core.connection.v1',
 'glitter_proto.ibc.core.types',
 'glitter_proto.ibc.core.types.v1',
 'glitter_proto.ibc.lightclients',
 'glitter_proto.ibc.lightclients.localhost',
 'glitter_proto.ibc.lightclients.localhost.v1',
 'glitter_proto.ibc.lightclients.solomachine',
 'glitter_proto.ibc.lightclients.solomachine.v1',
 'glitter_proto.ibc.lightclients.solomachine.v2',
 'glitter_proto.ibc.lightclients.tendermint',
 'glitter_proto.ibc.lightclients.tendermint.v1',
 'glitter_proto.ics23',
 'glitter_proto.tendermint',
 'glitter_proto.tendermint.abci',
 'glitter_proto.tendermint.crypto',
 'glitter_proto.tendermint.libs',
 'glitter_proto.tendermint.libs.bits',
 'glitter_proto.tendermint.p2p',
 'glitter_proto.tendermint.types',
 'glitter_proto.tendermint.version']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'glitter-proto',
    'version': '0.1.0',
    'description': '',
    'long_description': '',
    'author': 'Glitter Protocol',
    'author_email': 'ted@glitterprotocol.io',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)

==> glitter_proto-0.1.2.tar.gz: glitter_proto-0.1.2/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['glitter_proto',
 'glitter_proto.blockved',
 'glitter_proto.blockved.glitterchain',
 'glitter_proto.blockved.glitterchain.index',
 'glitter_proto.cosmos',
 'glitter_proto.cosmos.auth',
 'glitter_proto.cosmos.auth.v1beta1',
 'glitter_proto.cosmos.authz',
 'glitter_proto.cosmos.authz.v1beta1',
 'glitter_proto.cosmos.bank',
 'glitter_proto.cosmos.bank.v1beta1',
 'glitter_proto.cosmos.base',
 'glitter_proto.cosmos.base.abci',
 'glitter_proto.cosmos.base.abci.v1beta1',
 'glitter_proto.cosmos.base.kv',
 'glitter_proto.cosmos.base.kv.v1beta1',
 'glitter_proto.cosmos.base.query',
 'glitter_proto.cosmos.base.query.v1beta1',
 'glitter_proto.cosmos.base.reflection',
 'glitter_proto.cosmos.base.reflection.v1beta1',
 'glitter_proto.cosmos.base.reflection.v2alpha1',
 'glitter_proto.cosmos.base.snapshots',
 'glitter_proto.cosmos.base.snapshots.v1beta1',
 'glitter_proto.cosmos.base.store',
 'glitter_proto.cosmos.base.store.v1beta1',
 'glitter_proto.cosmos.base.tendermint',
 'glitter_proto.cosmos.base.tendermint.v1beta1',
 'glitter_proto.cosmos.base.v1beta1',
 'glitter_proto.cosmos.capability',
 'glitter_proto.cosmos.capability.v1beta1',
 'glitter_proto.cosmos.crisis',
 'glitter_proto.cosmos.crisis.v1beta1',
 'glitter_proto.cosmos.crypto',
 'glitter_proto.cosmos.crypto.ed25519',
 'glitter_proto.cosmos.crypto.multisig',
 'glitter_proto.cosmos.crypto.multisig.v1beta1',
 'glitter_proto.cosmos.crypto.secp256k1',
 'glitter_proto.cosmos.crypto.secp256r1',
 'glitter_proto.cosmos.distribution',
 'glitter_proto.cosmos.distribution.v1beta1',
 'glitter_proto.cosmos.evidence',
 'glitter_proto.cosmos.evidence.v1beta1',
 'glitter_proto.cosmos.feegrant',
 'glitter_proto.cosmos.feegrant.v1beta1',
 'glitter_proto.cosmos.genutil',
 'glitter_proto.cosmos.genutil.v1beta1',
 'glitter_proto.cosmos.gov',
 'glitter_proto.cosmos.gov.v1beta1',
 'glitter_proto.cosmos.mint',
 'glitter_proto.cosmos.mint.v1beta1',
 'glitter_proto.cosmos.params',
 'glitter_proto.cosmos.params.v1beta1',
 'glitter_proto.cosmos.slashing',
 'glitter_proto.cosmos.slashing.v1beta1',
 'glitter_proto.cosmos.staking',
 'glitter_proto.cosmos.staking.v1beta1',
 'glitter_proto.cosmos.tx',
 'glitter_proto.cosmos.tx.signing',
 'glitter_proto.cosmos.tx.signing.v1beta1',
 'glitter_proto.cosmos.tx.v1beta1',
 'glitter_proto.cosmos.upgrade',
 'glitter_proto.cosmos.upgrade.v1beta1',
 'glitter_proto.cosmos.vesting',
 'glitter_proto.cosmos.vesting.v1beta1',
 'glitter_proto.cosmos_proto',
 'glitter_proto.cosmwasm',
 'glitter_proto.cosmwasm.wasm',
 'glitter_proto.cosmwasm.wasm.v1',
 'glitter_proto.ethermint',
 'glitter_proto.ethermint.crypto',
 'glitter_proto.ethermint.crypto.v1',
 'glitter_proto.ethermint.crypto.v1.ethsecp256k1',
 'glitter_proto.ethermint.evm',
 'glitter_proto.ethermint.evm.v1',
 'glitter_proto.ethermint.feemarket',
 'glitter_proto.ethermint.feemarket.v1',
 'glitter_proto.ethermint.types',
 'glitter_proto.ethermint.types.v1',
 'glitter_proto.gogoproto',
 'glitter_proto.google',
 'glitter_proto.google.api',
 'glitter_proto.google.protobuf',
 'glitter_proto.google.protobuf.compiler',
 'glitter_proto.ibc',
 'glitter_proto.ibc.applications',
 'glitter_proto.ibc.applications.fee',
 'glitter_proto.ibc.applications.fee.v1',
 'glitter_proto.ibc.applications.interchain_accounts',
 'glitter_proto.ibc.applications.interchain_accounts.controller',
 'glitter_proto.ibc.applications.interchain_accounts.controller.v1',
 'glitter_proto.ibc.applications.interchain_accounts.host',
 'glitter_proto.ibc.applications.interchain_accounts.host.v1',
 'glitter_proto.ibc.applications.interchain_accounts.v1',
 'glitter_proto.ibc.applications.transfer',
 'glitter_proto.ibc.applications.transfer.v1',
 'glitter_proto.ibc.applications.transfer.v2',
 'glitter_proto.ibc.core',
 'glitter_proto.ibc.core.channel',
 'glitter_proto.ibc.core.channel.v1',
 'glitter_proto.ibc.core.client',
 'glitter_proto.ibc.core.client.v1',
 'glitter_proto.ibc.core.commitment',
 'glitter_proto.ibc.core.commitment.v1',
 'glitter_proto.ibc.core.connection',
 'glitter_proto.ibc.core.connection.v1',
 'glitter_proto.ibc.core.types',
 'glitter_proto.ibc.core.types.v1',
 'glitter_proto.ibc.lightclients',
 'glitter_proto.ibc.lightclients.localhost',
 'glitter_proto.ibc.lightclients.localhost.v1',
 'glitter_proto.ibc.lightclients.solomachine',
 'glitter_proto.ibc.lightclients.solomachine.v1',
 'glitter_proto.ibc.lightclients.solomachine.v2',
 'glitter_proto.ibc.lightclients.tendermint',
 'glitter_proto.ibc.lightclients.tendermint.v1',
 'glitter_proto.ics23',
 'glitter_proto.tendermint',
 'glitter_proto.tendermint.abci',
 'glitter_proto.tendermint.crypto',
 'glitter_proto.tendermint.libs',
 'glitter_proto.tendermint.libs.bits',
 'glitter_proto.tendermint.p2p',
 'glitter_proto.tendermint.types',
 'glitter_proto.tendermint.version']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'glitter-proto',
    'version': '0.1.2',
    'description': '',
    'long_description': 'The proto files of glitter-chain\n',
    'author': 'Glitter Protocol',
    'author_email': 'ted@glitterprotocol.io',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
